@@ -6,7 +6,7 @@ import os
 from pathlib import Path
 from black import format_str, FileMode
 import edgedb
-from pydantic import BaseModel, parse_raw_as, root_validator, ValidationError
+from pydantic import BaseModel, parse_raw_as, Field
 from devtools import debug
 from .introspection import (
     introspect_objects,
@@ -46,45 +46,26 @@ class NodeConfig(BaseModel):
 
 class DBConfig(BaseModel):
     vendor: DBVendor
-    host: str = None
-    host_var: str = None
-    password: str = None
-    password_var: str = None
-    port: int = 5656
+    dsn_: str = Field(..., alias="dsn")
     tls_security: TLSSecurity
     copy_config: str = None
     hydrate: bool = False
     nodes: T.Dict[str, NodeConfig] = dict()
 
-    @root_validator(pre=True)
-    def check_raw_or_vars(cls, values):
-        if values.get("host", None) is None:
-            if values.get("host_var", None) is None:
-                raise ValidationError("Must give either a host or a host_var")
-        if values.get("password", None) is None:
-            if values.get("password_var", None) is None:
-                raise ValidationError("Must give either a password or a password_var")
-        return values
+    @property
+    def is_plaintext_dsn(self) -> bool:
+        return self.dsn_.startswith("edgedb://")
 
     @property
-    def password_val(self) -> str:
-        return self.password or os.environ[self.password_var]
+    def dsn(self) -> str:
+        if self.is_plaintext_dsn:
+            return self.dsn_
+        return os.environ[self.dsn_]
 
-    @property
-    def host_val(self) -> str:
-        return self.host or os.environ[self.host_var]
-
-    @property
-    def password_variable(self) -> str:
-        return (
-            f'os.environ["{self.password_var}"]'
-            if self.password_var
-            else f'"{self.password}"'
-        )
-
-    @property
-    def host_variable(self) -> str:
-        return f'os.environ["{self.host_var}"]' if self.host_var else f'"{self.host}"'
+    def dsn_str(self) -> str:
+        if self.is_plaintext_dsn:
+            return f'"{self.dsn_}"'
+        return f"os.environ[{self.dsn_}]"
 
 
 PATH_TO_MODULE = "edgedb_orm"
@@ -695,10 +676,8 @@ def add_quotes_to_non_env_vars(s: str) -> str:
 def build_client(db_config: DBConfig) -> str:
     return f"""
 client = create_async_client(
+    dsn={db_config.dsn_str()},
     tls_security={add_quotes_to_non_env_vars(db_config.tls_security.value)},
-    host={db_config.host_variable},
-    password={db_config.password_variable},
-    port={db_config.port}
 )
     """
 
@@ -738,10 +717,8 @@ def get_nodes_to_hydrate(db_config: DBConfig) -> T.Set[str]:
 
 async def build_enums_from_config(db_config: DBConfig, include_strawberry: bool) -> str:
     client = edgedb.create_async_client(
+        dsn=db_config.dsn,
         tls_security=db_config.tls_security,
-        host=db_config.host_val,
-        password=db_config.password_val,
-        port=db_config.port,
     )
     enums_imports = build_enum_imports()
     enums_str = await build_enums(client, include_strawberry=include_strawberry)
@@ -757,10 +734,8 @@ async def build_from_config(
     dehydrate: bool = False,
 ) -> str:
     client = edgedb.create_async_client(
+        dsn=db_config.dsn,
         tls_security=db_config.tls_security,
-        host=db_config.host_val,
-        password=db_config.password_val,
-        port=db_config.port,
     )
     imports_str = imports(enums_module=enums_module)
     client_str = build_client(db_config)
